@@ -3,7 +3,7 @@
 
 set -eu
 
-SVN_BRANCH=upstream-svn/B2_1_Release
+SVN_BRANCH=upstream-svn/B2_5_Release
 
 HEAD=`git log --format=oneline $SVN_BRANCH -1|head -1|cut -d" " -f1`
 REV=`git log --format=full $HEAD -1 | grep 'git-svn-id: ' | sed -e 's/.\+@//; s/ .\+//'`
@@ -34,8 +34,8 @@ VER=`upstream_ver MAJOR_VER`.`upstream_ver MINOR_VER`.`upstream_ver REV_NO`
 
 echo "Version is $VER"
 
-TAR="firebird2.1-$VER~svn+${REV}"
+TAR="firebird3.0-$VER~svn+${REV}"
 
-git archive --format=tar --prefix=$TAR/ $HEAD | xz > ../$TAR.tar.xz
+git archive --format=tar --prefix=$TAR/ $HEAD | gzip -9 -n > ../$TAR.tar.gz
 
-sh debian/repack.sh --upstream-version $VER~svn+${REV} ../$TAR.tar.xz
+sh debian/repack.sh --upstream-version $VER~svn+${REV} ../$TAR.tar.gz
